@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Parse the UCI Bach choral harmony data set
 
-our $VERSION = '0.0204';
+our $VERSION = '0.0205';
 
 use Moo;
 use strictures 2;
@@ -105,28 +105,28 @@ sub parse {
 sub search {
     my ( $self, %args ) = @_;
 
-    my @results = ();
+    my %results = ();
 
     if ( $args{id} ) {
         my @ids = split /\s+/, $args{id};
 
         for my $id ( @ids ) {
-            push @results, { $id => $self->data->{$id} };
+            $results{$id} = $self->data->{$id};
         }
     }
     elsif ( $args{key} ) {
         my @keys = split /\s+/, $args{key};
 
         for my $id ( keys %{ $self->data } ) {
-            push @results, { $id => $self->data->{$id} }
+            $results{$id} = $self->data->{$id}
                 if any { $_ eq $self->data->{$id}{key} } @keys;
         }
     }
     elsif ( $args{bass} ) {
-        @results = $self->_search_param( bass => $args{bass} );
+        %results = $self->_search_param( bass => $args{bass} );
     }
     elsif ( $args{chord} ) {
-        @results = $self->_search_param( chord => $args{chord} );
+        %results = $self->_search_param( chord => $args{chord} );
     }
     elsif ( $args{notes} ) {
         my $and = $args{notes} =~ /&/ ? 1 : 0;
@@ -173,7 +173,7 @@ sub search {
                         }
                         else {
                             if ( any { defined $index{$_} && $i == $index{$_} } @notes ) {
-                                push @results, { $id => $self->data->{$id} };
+                                $results{$id} = $self->data->{$id};
                                 next ID;
                             }
                         }
@@ -194,19 +194,19 @@ sub search {
                         if exists $notes{$n};
                 }
 
-                push @results, { $id => $self->data->{$id} }
+                $results{$id} = $self->data->{$id}
                     if $i == scalar keys %notes;
             }
         }
     }
 
-    return \@results;
+    return \%results;
 }
 
 sub _search_param {
     my ( $self, $name, $param ) = @_;
 
-    my @results = ();
+    my %results = ();
 
     my $and = $param =~ /&/ ? 1 : 0;
     my $re  = $and ? qr/\s*&\s*/ : qr/\s+/;
@@ -227,7 +227,7 @@ sub _search_param {
             }
             else {
                 if ( any { $_ eq $event->{$name} } keys %notes ) {
-                    push @results, { $id => $self->data->{$id} };
+                    $results{$id} = $self->data->{$id};
                     next ID;
                 }
             }
@@ -241,12 +241,12 @@ sub _search_param {
                     if exists $notes{$n};
             }
 
-            push @results, { $id => $self->data->{$id} }
+            $results{$id} = $self->data->{$id}
                 if $i == scalar keys %notes;
         }
     }
 
-    return @results;
+    return %results;
 }
 
 
@@ -264,7 +264,7 @@ Music::BachChoralHarmony - Parse the UCI Bach choral harmony data set
 
 =head1 VERSION
 
-version 0.0204
+version 0.0205
 
 =head1 SYNOPSIS
 
@@ -362,10 +362,10 @@ B<accent> value and the resonating B<chord>.
   $songs = $bach->search( $k => $v ); # As in the SYNOPSIS above
 
 Search the parsed result B<data> by song B<id>s, B<key>s, B<bass>
-notes, B<chord>s, or individual B<notes> and return an array reference
-of hash references of the format:
+notes, B<chord>s, or individual B<notes> and return a hash reference
+of the format:
 
-  [ { $song_id => $song_data }, ... ],
+  { $song_id => $song_data, ... }
 
 The B<id>, and B<key> can be searched by single or multiple values
 returning all songs that match.  Note names must be separated with a
@@ -379,7 +379,7 @@ The B<bass>, B<chord>, and B<notes> can be searched either as C<or>
 
 =head1 SEE ALSO
 
-The F<eg/*> and F<t/01-methods.t> files
+The F<eg/*> and F<t/01-methods.t> files in this distribution.
 
 L<Moo>
 
@@ -390,18 +390,24 @@ L<File::ShareDir>
 L<List::Util>
 
 L<https://archive.ics.uci.edu/ml/datasets/Bach+Choral+Harmony>
+is the dataset itself.
 
 L<https://web.archive.org/web/20140515065053/http://www.jsbchorales.net/bwv.shtml>
-
-L<http://www.bach-chorales.com/BachChorales.htm>
+was the original site.
 
 L<https://github.com/ology/Bach-Chorales/blob/master/bin/key.py>
+is a program written to extract the key signature.
 
-L<https://github.com/ology/Bach-Chorales/blob/master/chorales.zip> are the collected MIDI files and PDF transcriptions.
+L<https://github.com/ology/Bach-Chorales/blob/master/chorales.zip>
+are the collected MIDI files and PDF transcriptions.
+
+L<http://www.bach-chorales.com/BachChorales.htm>
+is a Dancer2 web app that displays chord transitions.
 
 =head1 THANK YOU
 
-Dan Book (L<DBOOK|https://metacpan.org/author/DBOOK>) for the ShareDir clues.
+Dan Book (L<DBOOK|https://metacpan.org/author/DBOOK>)
+for the ShareDir clues.
 
 =head1 AUTHOR
 
